<?php
/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

/*
 * Created on 24 sept. 07 by AEL Sarl for
 * 
 * osCommerce, Open Source E-Commerce Solutions
 * http://www.oscommerce.com
 *
 * Copyright (c) 2003 osCommerce
 *
 * Released under the GNU General Public License
 * 
 */
 
class ImageDownload {
	
	public function __construct($opensi_web_id, $opensi_image_name, $opensi_image_size, $opensi_image_data) {
		
		$this->opensi_image_name = $opensi_image_name;
		$this->opensi_image_size = $opensi_image_size;
		$this->opensi_image_data = $opensi_image_data;
		$this->image_directory = '';
	}
	
	/**
	 * Downloads the image, and writes it
	 * 
	 * @return int	number of written bytes
	 */
	public function download() {
		if($this->prepareDownload())
			return $this->doDownload();
		
		return false;
	}
	
	/**
	 * Some operation before the download
	 * 
	 * @return boolean true on success, false on failure
	 */
	protected function prepareDownload() {
		return true;
	}
	 
	/**
	 * Writes the image
	 * 
	 * @return int	number of written bytes
	 */
	protected function doDownload() {
		$data_dir = DIR_FS_CATALOG_IMAGES;
		$fp = fopen($data_dir . $this->getRealImageName(), "w");
		return fwrite($fp, base64_decode($this->opensi_image_data), $this->opensi_image_size); 
	}

	/**
	 * Creates the directory
	 * 
	 * @param string $image_dir		directory to create in DIR_FS_CATALOG_IMAGES
	 * @return boolean true on success, false on failure
	 */	 
	protected function createImageDirectory($image_dir) {
		return mkdir(DIR_FS_CATALOG_IMAGES . $image_dir, 0775);
	}
}


class ProductImageDownload extends ImageDownload {
	
	public function __construct($opensi_web_id, $opensi_image_name, $opensi_image_size, $opensi_image_data) {
		parent::__construct($opensi_web_id, $opensi_image_name, $opensi_image_size, $opensi_image_data);
		
		// the product is a know product now
		$id_query = tep_db_query("SELECT po.Products_Id, p.products_image FROM PRODUCTS_TO_OPENSI po, " . TABLE_PRODUCTS . " p" .
		                         " WHERE po.Products_Id = p.products_id" .
		                         " AND po.Opensi_Web_Id = '" . $opensi_web_id . "'");
		$product = tep_db_fetch_array($id_query);
		$this->products_id = 0 + $product['Products_Id'];
		$this->products_image = $product['products_image'];
	}
	
	/**
	 * Get the real image name, that is the registered image name, or the new (opensi) name.
	 * The real name is the one that should be inserted in the database, and it is the name
	 * of the image file in the images directory (or special subdirectory by manufacturer name).
	 * 
	 * @return string	an image name
	 */
	protected function getRealImageName() {
		return (tep_not_null($this->products_image) ? $this->products_image : $this->opensi_image_name);
	}
	
	/**
	 * Create a directory for an image, if needed
	 * 
	 * @return boolean	true on success, or false
	 */
	protected function prepareDownload() {
		/*
		 * If the image does exists, we keep it's name,
		 * but overwrite it
		 */
		if (tep_not_null($this->products_image) && is_writable(DIR_FS_CATALOG_IMAGES . $this->products_image))
			return true;
		
		// create the directory, based on the manufacturer's name
		$manufacturer_query = tep_db_query(
		                             "SELECT manufacturers_name FROM " . TABLE_PRODUCTS . " p" .
		                             " LEFT JOIN " . TABLE_MANUFACTURERS . " m" .
		                             " ON p.manufacturers_id = m.manufacturers_id" .
		                             " WHERE p.products_id = " . $this->products_id);
		$manufacturer = tep_db_fetch_array($manufacturer_query);
		if (tep_not_null($image_dir = $manufacturer['manufacturers_name'])) {
			$image_dir = strtolower($image_dir);
			$image_dir = strtr($image_dir, " ", "_");
			if($this->createImageDirectory($image_dir)) {
				$this->opensi_image_name = $image_dir . "/" . $this->opensi_image_name;
				return true;
			}
			return false;
		}
		return true;
	}
	
	/**
	 * Update the image name in the database (table of products)
	 */
	public function updateImageName() {
		tep_db_query("UPDATE " . TABLE_PRODUCTS . 
                     " SET products_image = '" . $this->getRealImageName() . "'" .
                     " WHERE products_id = " . $this->products_id);
	}
}
?>
